@@ -21,7 +21,6 @@
 
 #include "config.h"
 
-#include "css-code.h"
 #include "gcal-application.h"
 #include "gcal-context.h"
 #include "gcal-debug.h"
@@ -41,9 +40,6 @@ struct _GcalApplication
 
   GtkWidget          *window;
 
-  GtkCssProvider     *provider;
-  GtkCssProvider     *colors_provider;
-
   gchar              *uuid;
   GDateTime          *initial_date;
 
@@ -95,73 +91,6 @@ enum
 
 static GParamSpec* properties[N_PROPS] = { NULL, };
 
-static void
-process_sources (GcalApplication *self)
-{
-  g_autoptr (GError) error = NULL;
-  g_autofree gchar *new_css_data = NULL;
-  g_auto (GStrv) new_css_snippets = NULL;
-  GcalManager *manager;
-  GList *calendars, *l;
-  GQuark color_id;
-  gint arr_length;
-  gint i = 0;
-
-  manager = gcal_context_get_manager (self->context);
-  calendars = gcal_manager_get_calendars (manager);
-  arr_length = g_list_length (calendars);
-  new_css_snippets = g_new0 (gchar*, arr_length + 2);
-  for (l = calendars; l; l = l->next, i++)
-    {
-      g_autofree gchar* color_str = NULL;
-      const GdkRGBA *color;
-      GcalCalendar *calendar;
-
-      calendar = GCAL_CALENDAR (l->data);
-
-      color = gcal_calendar_get_color (calendar);
-      color_str = gdk_rgba_to_string (color);
-      color_id = g_quark_from_string (color_str);
-
-      new_css_snippets[i] = g_strdup_printf (CSS_TEMPLATE, color_id, color_str);
-    }
-
-  g_list_free (calendars);
-
-  new_css_data = g_strjoinv ("\n", new_css_snippets);
-
-  gtk_css_provider_load_from_data (self->colors_provider, new_css_data, -1, &error);
-
-  if (error)
-    g_warning ("Error creating custom stylesheet. %s", error->message);
-}
-
-static void
-load_css_provider (GcalApplication *self)
-{
-  g_autoptr (GFile) css_file = NULL;
-  g_autofree gchar *theme_name = NULL;
-  g_autofree gchar *theme_uri = NULL;
-
-  /* Apply the CSS provider */
-  self->provider = gtk_css_provider_new ();
-  gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
-                                             GTK_STYLE_PROVIDER (self->provider),
-                                             GTK_STYLE_PROVIDER_PRIORITY_APPLICATION + 1);
-
-  /* Retrieve the theme name */
-  g_object_get (gtk_settings_get_default (), "gtk-theme-name", &theme_name, NULL);
-  theme_uri = g_strconcat ("resource:///org/gnome/calendar/theme/", theme_name, ".css", NULL);
-
-  /* Try and load the CSS file */
-  css_file = g_file_new_for_uri (theme_uri);
-
-  if (g_file_query_exists (css_file, NULL))
-    gtk_css_provider_load_from_file (self->provider, css_file, NULL);
-  else
-    gtk_css_provider_load_from_resource (self->provider, "/org/gnome/calendar/theme/Adwaita.css");
-}
-
 /*
  * Callbacks
  */
@@ -324,8 +253,6 @@ gcal_application_finalize (GObject *object)
   gcal_clear_date_time (&self->initial_date);
   g_clear_pointer (&self->uuid, g_free);
   g_clear_object (&self->context);
-  g_clear_object (&self->colors_provider);
-  g_clear_object (&self->provider);
   g_clear_object (&self->search_provider);
 
   G_OBJECT_CLASS (gcal_application_parent_class)->finalize (object);
@@ -369,16 +296,6 @@ gcal_application_activate (GApplication *application)
 
   self = GCAL_APPLICATION (application);
 
-  if (!self->provider)
-    load_css_provider (self);
-
-  if (self->colors_provider)
-    {
-      gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
-                                                 GTK_STYLE_PROVIDER (self->colors_provider),
-                                                 GTK_STYLE_PROVIDER_PRIORITY_APPLICATION + 2);
-    }
-
   if (!self->window)
     {
       if (!self->initial_date)
@@ -391,6 +308,7 @@ gcal_application_activate (GApplication *application)
                                     NULL);
 
       g_signal_connect (self->window, "destroy", G_CALLBACK (gtk_widget_destroyed), &self->window);
+      g_object_add_weak_pointer (G_OBJECT (self->window), (gpointer*) &self->window);
       gtk_widget_show (self->window);
     }
 
@@ -437,11 +355,6 @@ gcal_application_startup (GApplication *app)
 
   G_APPLICATION_CLASS (gcal_application_parent_class)->startup (app);
 
-  self->colors_provider = gtk_css_provider_new ();
-
-  /* Startup the manager */
-  gcal_context_startup (self->context);
-
   /* We're assuming the application is called as a service only by the shell search system */
   if ((g_application_get_flags (app) & G_APPLICATION_IS_SERVICE) != 0)
     g_application_set_inactivity_timeout (app, 3 * 60 * 1000);
@@ -449,6 +362,9 @@ gcal_application_startup (GApplication *app)
   /*  initialize libhandy */
   hdy_init();
 
+  /* Startup the manager */
+  gcal_context_startup (self->context);
+
   GCAL_EXIT;
 }
 
@@ -457,11 +373,14 @@ gcal_application_command_line (GApplication            *app,
                                GApplicationCommandLine *command_line)
 {
   g_autoptr (GVariant) option = NULL;
+  g_auto (GStrv) arguments = NULL;
   GcalApplication *self;
   GVariantDict *options;
   const gchar* date = NULL;
   const gchar* uuid = NULL;
   gsize length;
+  gint n_arguments;
+  gint i;
 
   GCAL_ENTRY;
 
@@ -510,6 +429,37 @@ gcal_application_command_line (GApplication            *app,
 
   g_application_activate (app);
 
+  arguments = g_application_command_line_get_arguments (command_line, &n_arguments);
+  if (n_arguments > 1)
+    {
+      g_autoptr (GHashTable) unique_files = NULL;
+      g_autoptr (GPtrArray) files = NULL;
+      gint n_files = 0;
+
+      files = g_ptr_array_new_full (n_arguments - 1, g_object_unref);
+      unique_files = g_hash_table_new (g_file_hash, (GEqualFunc) g_file_equal);
+
+      for (i = 1; i < n_arguments; i++)
+        {
+          g_autoptr (GFile) file = NULL;
+          const gchar *arg;
+
+          arg = arguments[i];
+          file = g_application_command_line_create_file_for_arg (command_line, arg);
+
+          if (g_str_has_prefix (arg, "-") || g_hash_table_contains (unique_files, file))
+            continue;
+
+          g_hash_table_add (unique_files, file);
+          g_ptr_array_add (files, g_steal_pointer (&file));
+
+          n_files++;
+        }
+
+      if (n_files > 0)
+        g_application_open (app, (GFile **) files->pdata, n_files, "");
+    }
+
   GCAL_RETURN (0);
 }
 
@@ -574,6 +524,24 @@ gcal_application_dbus_unregister (GApplication    *application,
   GCAL_EXIT;
 }
 
+static void
+gcal_application_open (GApplication  *application,
+                       GFile        **files,
+                       gint           n_files,
+                       const gchar   *hint)
+{
+  GcalApplication *self;
+
+  GCAL_ENTRY;
+
+  self = GCAL_APPLICATION (application);
+
+  g_application_activate (G_APPLICATION (application));
+  gcal_window_import_files (GCAL_WINDOW (self->window), files, n_files);
+
+  GCAL_EXIT;
+}
+
 static void
 gcal_application_class_init (GcalApplicationClass *klass)
 {
@@ -588,6 +556,7 @@ gcal_application_class_init (GcalApplicationClass *klass)
   application_class->activate = gcal_application_activate;
   application_class->startup = gcal_application_startup;
   application_class->command_line = gcal_application_command_line;
+  application_class->open = gcal_application_open;
   application_class->handle_local_options = gcal_application_handle_local_options;
   application_class->dbus_register = gcal_application_dbus_register;
   application_class->dbus_unregister = gcal_application_dbus_unregister;
@@ -610,17 +579,9 @@ gcal_application_class_init (GcalApplicationClass *klass)
 static void
 gcal_application_init (GcalApplication *self)
 {
-  GcalManager *manager;
-
   g_application_add_main_option_entries (G_APPLICATION (self), gcal_application_goptions);
 
   self->context = gcal_context_new ();
-
-  manager = gcal_context_get_manager (self->context);
-  g_signal_connect_swapped (manager, "calendar-added", G_CALLBACK (process_sources), self);
-  g_signal_connect_swapped (manager, "calendar-changed", G_CALLBACK (process_sources), self);
-  g_signal_connect_swapped (manager, "calendar-removed", G_CALLBACK (process_sources), self);
-
   self->search_provider = gcal_shell_search_provider_new (self->context);
 }
 
@@ -631,7 +592,7 @@ gcal_application_new (void)
   return g_object_new (gcal_application_get_type (),
                        "resource-base-path", "/org/gnome/calendar",
                        "application-id", APPLICATION_ID,
-                       "flags", G_APPLICATION_HANDLES_COMMAND_LINE,
+                       "flags", G_APPLICATION_HANDLES_COMMAND_LINE | G_APPLICATION_HANDLES_OPEN,
                        NULL);
 }
 
